#  /bin/bash

if [ $# -eq 0 ]; then
  echo "Usage:"
  echo "    $0 <prefix>"
  echo
  echo "        prefix: wxparaver installation PREFIX"
  exit
fi

PREFIX=${1}
BUNDLE_LIBS="wxparaver.app/Contents/Frameworks"
BUNDLE_BIN="wxparaver.app/Contents/MacOS/wxparaver"
BUNDLE_RESOURCES="wxparaver.app/Contents/Resources"

# Create directories
mkdir -p ${BUNDLE_LIBS}
mkdir -p wxparaver.app/Contents/MacOS
mkdir -p ${BUNDLE_RESOURCES}/cfgs
mkdir -p ${BUNDLE_RESOURCES}/share/doc/wxparaver_help_contents/

# Copy Resource Files
cp mac/Info.plist wxparaver.app/Contents
cp ${PREFIX}/share/workspaces.xml ${BUNDLE_RESOURCES}/share/
cp -R ${PREFIX}/cfgs/* ${BUNDLE_RESOURCES}/cfgs/
rm -f ${BUNDLE_RESOURCES}/cfgs/.cfgs*.tar.gz
cp -R ${PREFIX}/share/doc/wxparaver_help_contents/* ${BUNDLE_RESOURCES}/share/doc/wxparaver_help_contents/

# Copy paraver binary and libraries
cp ${PREFIX}/bin/wxparaver.bin ${BUNDLE_BIN}
cp ${PREFIX}/lib/paraver-kernel/libparaver-api.0.dylib ${BUNDLE_LIBS}
cp ${PREFIX}/lib/paraver-kernel/libparaver-kernel.0.dylib ${BUNDLE_LIBS}

# Copy dependency libraries
WXWIDGETS_3_0_LIBPATH="/opt/local/Library/Frameworks/wxWidgets.framework/Versions/wxWidgets/3.0/lib"
WXWIDGETS_3_0_LIBS="
libwx_osx_cocoau_aui-3.0.dylib
libwx_osx_cocoau_propgrid-3.0.dylib
libwx_osx_cocoau_richtext-3.0.dylib
libwx_osx_cocoau_xrc-3.0.dylib
libwx_osx_cocoau_webview-3.0.dylib 
libwx_osx_cocoau_html-3.0.dylib
libwx_osx_cocoau_qa-3.0.dylib
libwx_osx_cocoau_adv-3.0.dylib
libwx_osx_cocoau_core-3.0.dylib
libwx_baseu_xml-3.0.dylib
libwx_baseu_net-3.0.dylib
libwx_baseu-3.0.dylib"

for curlib in ${WXWIDGETS_3_0_LIBS}; do
  cp ${WXWIDGETS_3_0_LIBPATH}/${curlib} ${BUNDLE_LIBS}
done


SYS_LIBPATH="/opt/local/lib"
SYS_LIBS="
libboost_serialization-mt.dylib
libboost_date_time-mt.dylib
libboost_system-mt.dylib
libxml2.2.dylib
libz.1.dylib
libiconv.2.dylib
libpng16.16.dylib
libjpeg.9.dylib
libtiff.5.dylib
liblzma.5.dylib
libexpat.1.dylib
libssl.1.0.0.dylib
libcrypto.1.0.0.dylib"

for curlib in ${SYS_LIBS}; do
  cp ${SYS_LIBPATH}/${curlib} ${BUNDLE_LIBS}
done

chmod u+w ${BUNDLE_LIBS}/*

cp /System/Library/Frameworks/CFNetwork.framework/Versions/A/CFNetwork ${BUNDLE_LIBS}


# Set libraries location path
install_name_tool -change ${SYS_LIBPATH}/libboost_serialization-mt.dylib @executable_path/../Frameworks/libboost_serialization-mt.dylib ${BUNDLE_BIN}
install_name_tool -change ${SYS_LIBPATH}/libboost_date_time-mt.dylib @executable_path/../Frameworks/libboost_date_time-mt.dylib ${BUNDLE_BIN}
install_name_tool -change ${SYS_LIBPATH}/libboost_system-mt.dylib @executable_path/../Frameworks/libboost_system-mt.dylib ${BUNDLE_BIN}
install_name_tool -change ${SYS_LIBPATH}/libssl.1.0.0.dylib @executable_path/../Frameworks/libssl.1.0.0.dylib ${BUNDLE_BIN}
install_name_tool -change ${SYS_LIBPATH}/libcrypto.1.0.0.dylib @executable_path/../Frameworks/libcrypto.1.0.0.dylib ${BUNDLE_BIN}
install_name_tool -change ${SYS_LIBPATH}/libcrypto.1.0.0.dylib @executable_path/../Frameworks/libcrypto.1.0.0.dylib ${BUNDLE_LIBS}/libssl.1.0.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libz.1.dylib @executable_path/../Frameworks/libz.1.dylib ${BUNDLE_LIBS}/libssl.1.0.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libz.1.dylib @executable_path/../Frameworks/libz.1.dylib ${BUNDLE_LIBS}/libcrypto.1.0.0.dylib

for curlib in ${WXWIDGETS_3_0_LIBS}; do
  install_name_tool -change ${WXWIDGETS_3_0_LIBPATH}/${curlib} @executable_path/../Frameworks/${curlib} ${BUNDLE_BIN}
done
  
install_name_tool -change ${PREFIX}/lib/paraver-kernel/libparaver-kernel.0.dylib @executable_path/../Frameworks/libparaver-kernel.0.dylib ${BUNDLE_BIN}
install_name_tool -change ${PREFIX}/lib/paraver-kernel/libparaver-api.0.dylib @executable_path/../Frameworks/libparaver-api.0.dylib ${BUNDLE_BIN}

install_name_tool -change ${SYS_LIBPATH}/libboost_serialization-mt.dylib @executable_path/../Frameworks/libboost_serialization-mt.dylib ${BUNDLE_LIBS}/libparaver-kernel.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libboost_date_time-mt.dylib @executable_path/../Frameworks/libboost_date_time-mt.dylib ${BUNDLE_LIBS}/libparaver-kernel.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libxml2.2.dylib @executable_path/../Frameworks/libxml2.2.dylib ${BUNDLE_LIBS}/libparaver-kernel.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libz.1.dylib @executable_path/../Frameworks/libz.1.dylib ${BUNDLE_LIBS}/libparaver-kernel.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libiconv.2.dylib @executable_path/../Frameworks/libiconv.2.dylib ${BUNDLE_LIBS}/libparaver-kernel.0.dylib
install_name_tool -change ${SYS_LIBPATH}/liblzma.5.dylib @executable_path/../Frameworks/liblzma.5.dylib ${BUNDLE_LIBS}/libparaver-kernel.0.dylib

install_name_tool -change ${SYS_LIBPATH}/libboost_serialization-mt.dylib @executable_path/../Frameworks/libboost_serialization-mt.dylib ${BUNDLE_LIBS}/libparaver-api.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libboost_date_time-mt.dylib @executable_path/../Frameworks/libboost_date_time-mt.dylib ${BUNDLE_LIBS}/libparaver-api.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libxml2.2.dylib @executable_path/../Frameworks/libxml2.2.dylib ${BUNDLE_LIBS}/libparaver-api.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libz.1.dylib @executable_path/../Frameworks/libz.1.dylib ${BUNDLE_LIBS}/libparaver-api.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libiconv.2.dylib @executable_path/../Frameworks/libiconv.2.dylib ${BUNDLE_LIBS}/libparaver-api.0.dylib
install_name_tool -change ${SYS_LIBPATH}/liblzma.5.dylib @executable_path/../Frameworks/liblzma.5.dylib ${BUNDLE_LIBS}/libparaver-api.0.dylib

install_name_tool -change ${SYS_LIBPATH}/libz.1.dylib @executable_path/../Frameworks/libz.1.dylib ${BUNDLE_LIBS}/libpng16.16.dylib

install_name_tool -change ${SYS_LIBPATH}/liblzma.5.dylib @executable_path/../Frameworks/liblzma.5.dylib ${BUNDLE_LIBS}/libtiff.5.dylib
install_name_tool -change ${SYS_LIBPATH}/libjpeg.9.dylib @executable_path/../Frameworks/libjpeg.9.dylib ${BUNDLE_LIBS}/libtiff.5.dylib
install_name_tool -change ${SYS_LIBPATH}/libz.1.dylib @executable_path/../Frameworks/libz.1.dylib ${BUNDLE_LIBS}/libtiff.5.dylib

install_name_tool -change ${SYS_LIBPATH}/libz.1.dylib @executable_path/../Frameworks/libz.1.dylib ${BUNDLE_LIBS}/libwx_baseu-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libiconv.2.dylib @executable_path/../Frameworks/libiconv.2.dylib ${BUNDLE_LIBS}/libwx_baseu-3.0.dylib

install_name_tool -change ${SYS_LIBPATH}/libz.1.dylib @executable_path/../Frameworks/libz.1.dylib ${BUNDLE_LIBS}/libwx_baseu_net-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libiconv.2.dylib @executable_path/../Frameworks/libiconv.2.dylib ${BUNDLE_LIBS}/libwx_baseu_net-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_baseu-3.0.dylib) @executable_path/../Frameworks/libwx_baseu-3.0.dylib ${BUNDLE_LIBS}/libwx_baseu_net-3.0.dylib

install_name_tool -change ${SYS_LIBPATH}/libz.1.dylib @executable_path/../Frameworks/libz.1.dylib ${BUNDLE_LIBS}/libwx_baseu_xml-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libiconv.2.dylib @executable_path/../Frameworks/libiconv.2.dylib ${BUNDLE_LIBS}/libwx_baseu_xml-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_baseu-3.0.dylib) @executable_path/../Frameworks/libwx_baseu-3.0.dylib ${BUNDLE_LIBS}/libwx_baseu_xml-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libexpat.1.dylib @executable_path/../Frameworks/libexpat.1.dylib ${BUNDLE_LIBS}/libwx_baseu_xml-3.0.dylib

install_name_tool -change ${SYS_LIBPATH}/libpng16.16.dylib @executable_path/../Frameworks/libpng16.16.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_adv-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libz.1.dylib @executable_path/../Frameworks/libz.1.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_adv-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libjpeg.9.dylib @executable_path/../Frameworks/libjpeg.9.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_adv-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libtiff.5.dylib @executable_path/../Frameworks/libtiff.5.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_adv-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libiconv.2.dylib @executable_path/../Frameworks/libiconv.2.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_adv-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_osx_cocoau_core-3.0.dylib)  @executable_path/../Frameworks/libwx_osx_cocoau_core-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_adv-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_baseu-3.0.dylib) @executable_path/../Frameworks/libwx_baseu-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_adv-3.0.dylib

install_name_tool -change ${SYS_LIBPATH}/libpng16.16.dylib @executable_path/../Frameworks/libpng16.16.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_aui-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libz.1.dylib @executable_path/../Frameworks/libz.1.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_aui-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libjpeg.9.dylib @executable_path/../Frameworks/libjpeg.9.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_aui-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libtiff.5.dylib @executable_path/../Frameworks/libtiff.5.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_aui-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libiconv.2.dylib @executable_path/../Frameworks/libiconv.2.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_aui-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_osx_cocoau_adv-3.0.dylib) @executable_path/../Frameworks/libwx_osx_cocoau_adv-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_aui-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_osx_cocoau_core-3.0.dylib) @executable_path/../Frameworks/libwx_osx_cocoau_core-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_aui-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_baseu-3.0.dylib) @executable_path/../Frameworks/libwx_baseu-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_aui-3.0.dylib

install_name_tool -change ${SYS_LIBPATH}/libpng16.16.dylib @executable_path/../Frameworks/libpng16.16.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_core-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libz.1.dylib @executable_path/../Frameworks/libz.1.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_core-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libjpeg.9.dylib @executable_path/../Frameworks/libjpeg.9.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_core-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libtiff.5.dylib @executable_path/../Frameworks/libtiff.5.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_core-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libiconv.2.dylib @executable_path/../Frameworks/libiconv.2.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_core-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_baseu-3.0.dylib) @executable_path/../Frameworks/libwx_baseu-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_core-3.0.dylib

install_name_tool -change ${SYS_LIBPATH}/libpng16.16.dylib @executable_path/../Frameworks/libpng16.16.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_html-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libz.1.dylib @executable_path/../Frameworks/libz.1.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_html-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libjpeg.9.dylib @executable_path/../Frameworks/libjpeg.9.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_html-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libtiff.5.dylib @executable_path/../Frameworks/libtiff.5.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_html-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libiconv.2.dylib @executable_path/../Frameworks/libiconv.2.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_html-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_osx_cocoau_core-3.0.dylib) @executable_path/../Frameworks/libwx_osx_cocoau_core-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_html-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_baseu-3.0.dylib) @executable_path/../Frameworks/libwx_baseu-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_html-3.0.dylib

install_name_tool -change ${SYS_LIBPATH}/libpng16.16.dylib @executable_path/../Frameworks/libpng16.16.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_propgrid-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libz.1.dylib @executable_path/../Frameworks/libz.1.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_propgrid-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libjpeg.9.dylib @executable_path/../Frameworks/libjpeg.9.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_propgrid-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libtiff.5.dylib @executable_path/../Frameworks/libtiff.5.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_propgrid-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libiconv.2.dylib @executable_path/../Frameworks/libiconv.2.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_propgrid-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_osx_cocoau_adv-3.0.dylib) @executable_path/../Frameworks/libwx_osx_cocoau_adv-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_propgrid-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_osx_cocoau_core-3.0.dylib) @executable_path/../Frameworks/libwx_osx_cocoau_core-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_propgrid-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_baseu-3.0.dylib) @executable_path/../Frameworks/libwx_baseu-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_propgrid-3.0.dylib

install_name_tool -change ${SYS_LIBPATH}/libpng16.16.dylib @executable_path/../Frameworks/libpng16.16.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_qa-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libz.1.dylib @executable_path/../Frameworks/libz.1.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_qa-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libjpeg.9.dylib @executable_path/../Frameworks/libjpeg.9.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_qa-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libtiff.5.dylib @executable_path/../Frameworks/libtiff.5.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_qa-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libiconv.2.dylib @executable_path/../Frameworks/libiconv.2.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_qa-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_osx_cocoau_core-3.0.dylib) @executable_path/../Frameworks/libwx_osx_cocoau_core-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_qa-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_baseu-3.0.dylib) @executable_path/../Frameworks/libwx_baseu-3.0.dylib  ${BUNDLE_LIBS}/libwx_osx_cocoau_qa-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_baseu_xml-3.0.dylib) @executable_path/../Frameworks/libwx_baseu_xml-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_qa-3.0.dylib

install_name_tool -change ${SYS_LIBPATH}/libpng16.16.dylib @executable_path/../Frameworks/libpng16.16.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_richtext-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libz.1.dylib @executable_path/../Frameworks/libz.1.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_richtext-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libjpeg.9.dylib @executable_path/../Frameworks/libjpeg.9.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_richtext-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libtiff.5.dylib @executable_path/../Frameworks/libtiff.5.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_richtext-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libiconv.2.dylib @executable_path/../Frameworks/libiconv.2.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_richtext-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_osx_cocoau_adv-3.0.dylib) @executable_path/../Frameworks/libwx_osx_cocoau_adv-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_richtext-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_osx_cocoau_html-3.0.dylib) @executable_path/../Frameworks/libwx_osx_cocoau_html-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_richtext-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_baseu_xml-3.0.dylib) @executable_path/../Frameworks/libwx_baseu_xml-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_richtext-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_osx_cocoau_core-3.0.dylib) @executable_path/../Frameworks/libwx_osx_cocoau_core-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_richtext-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_baseu-3.0.dylib) @executable_path/../Frameworks/libwx_baseu-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_richtext-3.0.dylib

install_name_tool -change ${SYS_LIBPATH}/libpng16.16.dylib @executable_path/../Frameworks/libpng16.16.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_webview-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libz.1.dylib @executable_path/../Frameworks/libz.1.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_webview-3.0.dylib 
install_name_tool -change ${SYS_LIBPATH}/libjpeg.9.dylib @executable_path/../Frameworks/libjpeg.9.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_webview-3.0.dylib 
install_name_tool -change ${SYS_LIBPATH}/libtiff.5.dylib @executable_path/../Frameworks/libtiff.5.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_webview-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libiconv.2.dylib @executable_path/../Frameworks/libiconv.2.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_webview-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_osx_cocoau_core-3.0.dylib) @executable_path/../Frameworks/libwx_osx_cocoau_core-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_webview-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_baseu-3.0.dylib) @executable_path/../Frameworks/libwx_baseu-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_webview-3.0.dylib

install_name_tool -change ${SYS_LIBPATH}/libpng16.16.dylib @executable_path/../Frameworks/libpng16.16.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_xrc-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libz.1.dylib @executable_path/../Frameworks/libz.1.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_xrc-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libjpeg.9.dylib @executable_path/../Frameworks/libjpeg.9.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_xrc-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libtiff.5.dylib @executable_path/../Frameworks/libtiff.5.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_xrc-3.0.dylib
install_name_tool -change ${SYS_LIBPATH}/libiconv.2.dylib @executable_path/../Frameworks/libiconv.2.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_xrc-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_osx_cocoau_html-3.0.dylib) @executable_path/../Frameworks/libwx_osx_cocoau_html-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_xrc-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_osx_cocoau_adv-3.0.dylib) @executable_path/../Frameworks/libwx_osx_cocoau_adv-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_xrc-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_osx_cocoau_core-3.0.dylib) @executable_path/../Frameworks/libwx_osx_cocoau_core-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_xrc-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_baseu_xml-3.0.dylib) @executable_path/../Frameworks/libwx_baseu_xml-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_xrc-3.0.dylib
install_name_tool -change $(greadlink -f ${WXWIDGETS_3_0_LIBPATH}/libwx_baseu-3.0.dylib) @executable_path/../Frameworks/libwx_baseu-3.0.dylib ${BUNDLE_LIBS}/libwx_osx_cocoau_xrc-3.0.dylib

install_name_tool -change ${SYS_LIBPATH}/libz.1.dylib @executable_path/../Frameworks/libz.1.dylib ${BUNDLE_LIBS}/libxml2.2.dylib
install_name_tool -change ${SYS_LIBPATH}/liblzma.5.dylib @executable_path/../Frameworks/liblzma.5.dylib ${BUNDLE_LIBS}/libxml2.2.dylib
install_name_tool -change ${SYS_LIBPATH}/libiconv.2.dylib @executable_path/../Frameworks/libiconv.2.dylib ${BUNDLE_LIBS}/libxml2.2.dylib

install_name_tool -change /System/Library/Frameworks/CFNetwork.framework/Versions/A/CFNetwork @executable_path/../Frameworks/CFNetwork ${BUNDLE_LIBS}/libwx_osx_cocoau_core-3.0.dylib

